translate.convert.po2symb

Package translate :: Package convert :: Module po2symb |
[hide private]
[frames] | no frames]

# Module po2symb

source code

convert Gettext PO localization files to Symbian translation files.

Functions | [hide private]
escape(text) | source code
replace_header_items(ps, replacments) | source code
parse(ps, header_replacements, body_replacements) | source code
line_saver(charset) | source code
write_symbian(f, header_replacements, body_replacements) | source code
build_location_index(store) | source code
build_header_index(store) | source code
convert_symbian(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt") | source code
main(argv=None) | source code

Imports: sys, factory, po_escape_map, read_while, charset_re, string_entry_re, re, eat_whitespace, header_item_re, header_item_or_end_re, read_charset, ParseState, skip_no_translate, identity